from django.apps import AppConfig


class DjangoObjectDetailConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "django_object_detail"
    verbose_name = "Django Object Detail"
